@@ -183,10 +183,10 @@ class ToolBit(object):
             self._setupBitShape(obj)
         self.onDocumentRestored(obj)
 
-    def __getstate__(self):
+    def dumps(self):
         return None
 
-    def __setstate__(self, state):
+    def loads(self, state):
         for obj in FreeCAD.ActiveDocument.Objects:
             if hasattr(obj, "Proxy") and obj.Proxy == self:
                 self.obj = obj
